==> qtjambi-xml-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiXml/QXmlNamespaceSupport_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtXml/qxml.h>
#include <QtCore/QVariant>
#include "utils_p.h"
#include <QtCore/qstring.h>
#include <QtCore/QStringList>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QXmlNamespaceSupport(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QXmlNamespaceSupport")
    QXmlNamespaceSupport *_ptr = reinterpret_cast<QXmlNamespaceSupport *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QXmlNamespaceSupport()
void __qt_construct_QXmlNamespaceSupport_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlNamespaceSupport()")
    Q_UNUSED(__java_arguments)
    QXmlNamespaceSupport *__qt_this = new(__qtjambi_ptr) QXmlNamespaceSupport();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QXmlNamespaceSupport
void __qt_destruct_QXmlNamespaceSupport(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QXmlNamespaceSupport")
    reinterpret_cast<QXmlNamespaceSupport*>(ptr)->~QXmlNamespaceSupport();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QXmlNamespaceSupport::QXmlNamespaceSupport()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_initialize_1native__Lio_qt_xml_QXmlNamespaceSupport_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlNamespaceSupport::QXmlNamespaceSupport()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlNamespaceSupport_0, sizeof(QXmlNamespaceSupport), typeid(QXmlNamespaceSupport), false, &deleter_QXmlNamespaceSupport, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNamespaceSupport::popContext()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_popContext_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::popContext()", __qt_this)
        __qt_this->popContext();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNamespaceSupport::prefix(QString)const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_prefix_1native_1cref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring arg__1)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::prefix(QString)const", __qt_this)
        QString  __qt_arg__1 = qtjambi_cast<QString >(__jni_env, arg__1);
        QString __qt_return_value = __qt_this->prefix(__qt_arg__1);
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNamespaceSupport::prefixes()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_prefixes_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::prefixes()const", __qt_this)
        QStringList __qt_return_value = __qt_this->prefixes();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNamespaceSupport::prefixes(QString)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_prefixes_1native_1cref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring arg__1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::prefixes(QString)const", __qt_this)
        QString  __qt_arg__1 = qtjambi_cast<QString >(__jni_env, arg__1);
        QStringList __qt_return_value = __qt_this->prefixes(__qt_arg__1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNamespaceSupport::processName(QString,bool,QString&,QString&)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_processName_1native_1cref_1QString_1bool_1ref_1QString_1ref_1QString_1constfct__JLjava_lang_String_2Z)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring arg__1,
 jboolean arg__2)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::processName(QString,bool,QString&,QString&)const", __qt_this)
        QString  __qt_arg__1 = qtjambi_cast<QString >(__jni_env, arg__1);
        QString __qt_arg__3;
        QString __qt_arg__4;
        __qt_this->processName(__qt_arg__1, static_cast<bool>(arg__2), __qt_arg__3, __qt_arg__4);
        __java_return_value = Java::QtXml::QXmlNamespaceSupport$ProcessedName::newInstance(__jni_env, qtjambi_cast<jstring>(__jni_env, __qt_arg__3), qtjambi_cast<jstring>(__jni_env, __qt_arg__4));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNamespaceSupport::pushContext()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_pushContext_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::pushContext()", __qt_this)
        __qt_this->pushContext();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNamespaceSupport::reset()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_reset_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::reset()", __qt_this)
        __qt_this->reset();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNamespaceSupport::setPrefix(QString,QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_setPrefix_1native_1cref_1QString_1cref_1QString__JLjava_lang_String_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring arg__1,
 jstring arg__2)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::setPrefix(QString,QString)", __qt_this)
        QString  __qt_arg__1 = qtjambi_cast<QString >(__jni_env, arg__1);
        QString  __qt_arg__2 = qtjambi_cast<QString >(__jni_env, arg__2);
        __qt_this->setPrefix(__qt_arg__1, __qt_arg__2);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNamespaceSupport::splitName(QString,QString&,QString&)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_splitName_1native_1cref_1QString_1ref_1QString_1ref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring arg__1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::splitName(QString,QString&,QString&)const", __qt_this)
        QString  __qt_arg__1 = qtjambi_cast<QString >(__jni_env, arg__1);
        QString __qt_arg__2;
        QString __qt_arg__3;
        __qt_this->splitName(__qt_arg__1, __qt_arg__2, __qt_arg__3);
        __java_return_value = Java::QtXml::QXmlNamespaceSupport$SplitName::newInstance(__jni_env, qtjambi_cast<jstring>(__jni_env, __qt_arg__2), qtjambi_cast<jstring>(__jni_env, __qt_arg__3));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNamespaceSupport::uri(QString)const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_uri_1native_1cref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring arg__1)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::uri(QString)const", __qt_this)
        QString  __qt_arg__1 = qtjambi_cast<QString >(__jni_env, arg__1);
        QString __qt_return_value = __qt_this->uri(__qt_arg__1);
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QXmlNamespaceSupport(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QXmlNamespaceSupport>("QXmlNamespaceSupport", "io/qt/xml/QXmlNamespaceSupport");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QXmlNamespaceSupport, {
        ConstructorInfo(&__qt_construct_QXmlNamespaceSupport_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QXmlNamespaceSupport);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-xml-debuginfo-windows-x64-5.15.20.jar: sources/QtJambiXml/QXmlNamespaceSupport_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtXml/qxml.h>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qstring.h>
#include "utils_p.h"

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QXmlNamespaceSupport(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QXmlNamespaceSupport")
    QXmlNamespaceSupport *_ptr = reinterpret_cast<QXmlNamespaceSupport *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QXmlNamespaceSupport()
void __qt_construct_QXmlNamespaceSupport(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlNamespaceSupport()")
    Q_UNUSED(__java_arguments)
    QXmlNamespaceSupport *__qt_this = new(__qtjambi_ptr) QXmlNamespaceSupport();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QXmlNamespaceSupport::QXmlNamespaceSupport()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_initialize_1native__Lio_qt_xml_QXmlNamespaceSupport_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlNamespaceSupport::QXmlNamespaceSupport()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlNamespaceSupport, sizeof(QXmlNamespaceSupport), typeid(QXmlNamespaceSupport), false, &deleter_QXmlNamespaceSupport, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QXmlNamespaceSupport
void __qt_destruct_QXmlNamespaceSupport(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QXmlNamespaceSupport")
    reinterpret_cast<QXmlNamespaceSupport*>(ptr)->~QXmlNamespaceSupport();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QXmlNamespaceSupport::popContext()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_popContext_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::popContext()", __qt_this)
        __qt_this->popContext();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNamespaceSupport::prefix(QString)const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_prefix_1native_1cref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring arg__1)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::prefix(QString)const", __qt_this)
        QString  __qt_arg__1 = qtjambi_cast<QString>(__jni_env, arg__1);
        QString __qt_return_value = __qt_this->prefix(__qt_arg__1);
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNamespaceSupport::prefixes()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_prefixes_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::prefixes()const", __qt_this)
        QStringList __qt_return_value = __qt_this->prefixes();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNamespaceSupport::prefixes(QString)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_prefixes_1native_1cref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring arg__1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::prefixes(QString)const", __qt_this)
        QString  __qt_arg__1 = qtjambi_cast<QString>(__jni_env, arg__1);
        QStringList __qt_return_value = __qt_this->prefixes(__qt_arg__1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNamespaceSupport::processName(QString,bool,QString&,QString&)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_processName_1native_1cref_1QString_1bool_1ref_1QString_1ref_1QString_1constfct__JLjava_lang_String_2Z)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring arg__1,
 jboolean arg__2)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::processName(QString,bool,QString&,QString&)const", __qt_this)
        QString  __qt_arg__1 = qtjambi_cast<QString>(__jni_env, arg__1);
        QString __qt_arg__3;
        QString __qt_arg__4;
        __qt_this->processName(__qt_arg__1, static_cast<bool>(arg__2), __qt_arg__3, __qt_arg__4);
        __java_return_value = Java::QtXml::QXmlNamespaceSupport$ProcessedName::newInstance(__jni_env, qtjambi_cast<jstring>(__jni_env, __qt_arg__3), qtjambi_cast<jstring>(__jni_env, __qt_arg__4));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNamespaceSupport::pushContext()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_pushContext_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::pushContext()", __qt_this)
        __qt_this->pushContext();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNamespaceSupport::reset()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_reset_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::reset()", __qt_this)
        __qt_this->reset();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNamespaceSupport::setPrefix(QString,QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_setPrefix_1native_1cref_1QString_1cref_1QString__JLjava_lang_String_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring arg__1,
 jstring arg__2)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::setPrefix(QString,QString)", __qt_this)
        QString  __qt_arg__1 = qtjambi_cast<QString>(__jni_env, arg__1);
        QString  __qt_arg__2 = qtjambi_cast<QString>(__jni_env, arg__2);
        __qt_this->setPrefix(__qt_arg__1, __qt_arg__2);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNamespaceSupport::splitName(QString,QString&,QString&)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_splitName_1native_1cref_1QString_1ref_1QString_1ref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring arg__1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::splitName(QString,QString&,QString&)const", __qt_this)
        QString  __qt_arg__1 = qtjambi_cast<QString>(__jni_env, arg__1);
        QString __qt_arg__2;
        QString __qt_arg__3;
        __qt_this->splitName(__qt_arg__1, __qt_arg__2, __qt_arg__3);
        __java_return_value = Java::QtXml::QXmlNamespaceSupport$SplitName::newInstance(__jni_env, qtjambi_cast<jstring>(__jni_env, __qt_arg__2), qtjambi_cast<jstring>(__jni_env, __qt_arg__3));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNamespaceSupport::uri(QString)const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QXmlNamespaceSupport_uri_1native_1cref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring arg__1)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNamespaceSupport *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNamespaceSupport>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNamespaceSupport::uri(QString)const", __qt_this)
        QString  __qt_arg__1 = qtjambi_cast<QString>(__jni_env, arg__1);
        QString __qt_return_value = __qt_this->uri(__qt_arg__1);
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QXmlNamespaceSupport(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QXmlNamespaceSupport>("QXmlNamespaceSupport", "io/qt/xml/QXmlNamespaceSupport");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QXmlNamespaceSupport, {
        ConstructorInfo(&__qt_construct_QXmlNamespaceSupport, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QXmlNamespaceSupport);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
